﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Windows;
using System.Windows.Media.Imaging;
using System.Xml.Linq;

namespace StockChartKnocker
{
    public partial class MainWindow : Window
    {
        public const string _FILE = @"StockList.xml";
        private List<StockDto> _list = new List<StockDto>();
        private int index = 0;
        public MainWindow()
        {
            InitializeComponent();

            Loaded += (_, __) =>
                {
                    if(!File.Exists(_FILE))
                    {
                        var msg = string.Format("{0}に{1}を配置して下さい。",Environment.CurrentDirectory,_FILE);
                        throw new FileNotFoundException(msg);
                    }

                    var root = XElement.Load(_FILE);

                    root.Descendants("Stock").ToList().ForEach(element =>
                    {
                        _list.Add(new StockDto()
                        {
                            Enable = bool.Parse(element.Attribute("Enable").Value),
                            Code = element.Attribute("Code").Value,
                            MarketCode = element.Attribute("MarketCode").Value,
                            Name = element.Attribute("Name").Value,
                            Market = element.Attribute("Market").Value
                        });
                    });
                };

            ckbEnable.Unchecked += (_, __) => _list[index].Enable = false;
            ckbEnable.Checked += (_, __) => _list[index].Enable = true;

            btnNext.Click += (_, __) =>
                {
                    if(_list.Count(dto=>dto.Enable) == 0)
                    {
                        return;
                    }

                    var candidate = _list.Where(dto => dto.Enable).ElementAtOrDefault(index);

                    var target = candidate ?? _list[index = 0];

                    ckbEnable.IsChecked = true;
                    lblStockName.Content = string.Format("{0} {1} {2}", target.Code, target.Market, target.Name);

                    var path = string.Format("http://chart.yahoo.co.jp/?code={0}.{1}&tm=3m&type=c&log=off&size=m&over=m65,m130,s&add=v&comp=", target.Code, target.MarketCode);
                    imgMain.Source = new BitmapImage(new Uri(path)); 

                    index++;
                };

            btnSetting.Click += (_, __) =>
                {
                    new SettingsWindow(_list).ShowDialog();
                    index = 0;
                };

            Closing += (_, __) =>
            {
                var doc = new XDocument();
                var root = new XElement("Stocks");

                _list.ForEach(stock =>
                {
                    root.Add(new XElement("Stock",
                        new XAttribute("Enable", stock.Enable),
                        new XAttribute("Code", stock.Code),
                        new XAttribute("MarketCode", stock.MarketCode),
                        new XAttribute("Name", stock.Name),
                        new XAttribute("Market", stock.Market)
                        ));
                });

                doc.Add(root);
                doc.Save(_FILE);
            };

        }
    }

    public class StockDto
    {
        public bool Enable { get; set; }
        public string Code { get; set; }
        public string MarketCode { get; set; }
        public string Name { get; set; }
        public string Market { get; set; }
    }
}
